import os
import pydoc
from setuptools import Extension, find_packages, setup

from Cython.Build import cythonize
import numpy as np

IMPROVE_DIR = 'improveai'
CYTHON_MODULE_DIR = 'cythonized_feature_encoding'

# EXPECTED_CYTHON_VERSION = '0.29.14'
# EXPECTED_NUMPY_VERSION = '1.19.2'

if __name__ == '__main__':

    # installed_packages = [pkg.name for pkg in pydoc.pkgutil.iter_modules()]
    # if 'Cython' not in installed_packages:
    #     os.system(f'pip3 install cython>={EXPECTED_CYTHON_VERSION}')

    # if 'numpy' not in installed_packages:
    #     os.system(f'pip3 install {EXPECTED_NUMPY_VERSION}')

    cython_feature_encoding_utils_path_str = \
        os.sep.join(
            [IMPROVE_DIR, CYTHON_MODULE_DIR, 'cythonized_feature_encoding_utils.pyx'])

    cython_feature_encoding_utils_ext = \
        Extension(
            '{}.{}.cythonized_feature_encoding_utils'.format(IMPROVE_DIR, CYTHON_MODULE_DIR),
            sources=[cython_feature_encoding_utils_path_str],
            include_dirs=[np.get_include(), os.sep.join(['.', IMPROVE_DIR, CYTHON_MODULE_DIR])])

    cython_feature_encoder_path_str = \
        os.sep.join(
            [IMPROVE_DIR, CYTHON_MODULE_DIR, 'cythonized_feature_encoder.pyx'])

    cython_feature_encoder_ext = \
        Extension(
            '{}.{}.src.cythonized_feature_encoder'.format(IMPROVE_DIR, CYTHON_MODULE_DIR),
            sources=[cython_feature_encoder_path_str],
            include_dirs=[np.get_include(), os.sep.join(['.', IMPROVE_DIR, CYTHON_MODULE_DIR])])

    setup(name='improveai-test',
          version='0.702',
          description='Decision API',
          author='Justin Chapweske',
          author_email='',
          url='https://github.com/improve-ai/python-sdk',
          packages=find_packages(exclude=['*tests*', '*old_files*', '*experiments*']),
          install_requires=["numpy>=1.19.2", "setuptools", "wheel", "Cython>=0.29.21"],  # + install_reqs,
          ext_modules=cythonize([cython_feature_encoding_utils_ext, cython_feature_encoder_ext], language_level="3"),
          include_dirs=[np.get_include(), '.'],
          include_package_data=True,
          zip_safe=False)
